# -*- coding: utf-8 -*-
import requests
from pagador import settings


def envia_alteracao_de_situacao_de_pedido(pedido_numero, situacao, conta_id):
    url = "{}pedido/{}/situacao/{}/conta/{}/api_pagador".format(settings.QUEUE_URL, pedido_numero, situacao, conta_id)
    return requests.put(url)
